@@ -1,26 +1,28 @@
 import asyncio
-import janda
-import requests
 import os
 import re
 import time
+
+import janda
+import requests
+from inputimeout import TimeoutOccurred
+
+from .pdf import process_pdf
+from .utils.const import TOMOE_HTML
 from .utils.misc import (
     choose,
-    split_name,
     get_size,
-    convert_html_to_pdf,
-    project,
     get_size_folder,
-    nums,
     log_data,
     log_file,
     log_final,
     log_warn,
+    nums,
+    project,
+    split_name,
 )
-from inputimeout import inputimeout, TimeoutOccurred
 
 simply = janda.SimplyHentai()
-t: str = "tomoe.html"
 
 
 async def get_sim(ids=choose().simply):
@@ -92,7 +94,7 @@ async def process_simplyh(id: str):
 
                 print(f"Directory: {os.path.abspath(neat_dir)}")
 
-                with open(neat_dir + "/" + t, "x", encoding="utf-8") as f:
+                with open(neat_dir + "/" + TOMOE_HTML, "x", encoding="utf-8") as f:
                     f.write("<html><center><body>")
                     f.write(f"<h1>{neat_dir}</h1>")
 
@@ -104,35 +106,6 @@ async def process_simplyh(id: str):
                     f.close()
 
                 try:
-                    desired = inputimeout(
-                        prompt="Do you want to render it all to .pdf? (y/n) ",
-                        timeout=10,
-                    )
-                    to_pdf = desired
-
-                    if to_pdf == "y":
-                        try:
-                            source = open(f"{neat_dir}/{t}")
-                            output = f"{neat_dir}/{set_name}.pdf"
-                            filepdf = output.rsplit("/", 1)[-1]
-
-                            convert_html_to_pdf(source, output)
-                            print(
-                                f"Successfully rendered to {filepdf} | {get_size(output)} MB"
-                            )
-
-                        except Exception as e:
-                            print(f"Something went wrong while converting to pdf: {e}")
-
-                    elif to_pdf == "n":
-                        print("Okay")
-                        os.remove(neat_dir + "/" + t)
-                        return
-
-                    else:
-                        print("Invalid input")
-                        os.remove(neat_dir + "/" + t)
-                        return
-
+                    process_pdf(neat_dir, set_name)
                 except TimeoutOccurred:
                     print(f"Timeout occurred, not rendering pdf {id}")
